pub enum OpusError {
InvalidPacket,
InternalError,
BufferTooSmall,
InvalidArgument(&'static str),
}Expand description
Errors returned by the public Opus decoding API.
Variants
InvalidPacket
The provided Opus packet is malformed or internally inconsistent.
InternalError
The decoder hit an internal unsupported or unexpected state.
BufferTooSmall
The output PCM buffer is too small for the decoded frame.
InvalidArgument(&'static str)
One of the public API arguments is invalid.